==> localnews-news-model-1.3.0.2-sources.jar: com/bxm/localnews/news/vo/Video.java <==
package com.bxm.localnews.news.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * t_video
 * @author 
 */
public class Video implements Serializable {
    /**
     * 主键
     */
    private Long id;

    /**
     * 第三方导入的ID
     */
    private Long tid;

    /**
     * 视频描述
     */
    private String description;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 视频图片
     */
    private String videoImg;

    /**
     * 视频播放地址
     */
    private String videoUrl;

    /**
     * 作者ID
     */
    private Long authorId;

    /**
     * 作者头像
     */
    private String authorImg;

    /**
     * 作者名称
     */
    private String authorName;

    /**
     * 视频创建时间
     */
    private Date createTime;

    /**
     * 爬取时间
     */
    private Date issueTime;

    /**
     * 视频状态（0：无效，1：有效）
     */
    private Byte status;

    /**
     * 评论次数
     */
    private Long commentCount;

    /**
     * 分享次数
     */
    private Long shareCount;

    /**
     * 点赞次数
     */
    private Long likeCount;

    /**
     * 点击播放次数
     */
    private Long clickCount;

    private static final long serialVersionUID = 1L;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getVideoImg() {
        return videoImg;
    }

    public void setVideoImg(String videoImg) {
        this.videoImg = videoImg;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public Long getAuthorId() {
        return authorId;
    }

    public void setAuthorId(Long authorId) {
        this.authorId = authorId;
    }

    public String getAuthorImg() {
        return authorImg;
    }

    public void setAuthorImg(String authorImg) {
        this.authorImg = authorImg;
    }

    public String getAuthorName() {
        return authorName;
    }

    public void setAuthorName(String authorName) {
        this.authorName = authorName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getIssueTime() {
        return issueTime;
    }

    public void setIssueTime(Date issueTime) {
        this.issueTime = issueTime;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getShareCount() {
        return shareCount;
    }

    public void setShareCount(Long shareCount) {
        this.shareCount = shareCount;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }
}

==> localnews-news-model-1.3.2-sources.jar: com/bxm/localnews/news/vo/Video.java <==
package com.bxm.localnews.news.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * t_video
 * @author 
 */
public class Video implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 第三方导入的ID
     */
    private Long tid;

    /**
     * 视频描述
     */
    private String description;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 视频图片
     */
    private String videoImg;

    /**
     * 视频播放地址
     */
    private String videoUrl;

    /**
     * 作者ID
     */
    private Long authorId;

    /**
     * 作者头像
     */
    private String authorImg;

    /**
     * 作者名称
     */
    private String authorName;

    /**
     * 视频创建时间
     */
    private Date createTime;

    /**
     * 爬取时间
     */
    private Date issueTime;

    /**
     * 视频状态（0：无效，1：有效）
     */
    private Byte status;

    /**
     * 评论次数
     */
    private Long commentCount;

    /**
     * 分享次数
     */
    private Long shareCount;

    /**
     * 点赞次数
     */
    private Long likeCount;

    /**
     * 点击播放次数
     */
    private Long clickCount;

    private Double widthRatio;

    public Double getWidthRatio() {
        return widthRatio;
    }

    public void setWidthRatio(Double widthRatio) {
        this.widthRatio = widthRatio;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getVideoImg() {
        return videoImg;
    }

    public void setVideoImg(String videoImg) {
        this.videoImg = videoImg;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public Long getAuthorId() {
        return authorId;
    }

    public void setAuthorId(Long authorId) {
        this.authorId = authorId;
    }

    public String getAuthorImg() {
        return authorImg;
    }

    public void setAuthorImg(String authorImg) {
        this.authorImg = authorImg;
    }

    public String getAuthorName() {
        return authorName;
    }

    public void setAuthorName(String authorName) {
        this.authorName = authorName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getIssueTime() {
        return issueTime;
    }

    public void setIssueTime(Date issueTime) {
        this.issueTime = issueTime;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getShareCount() {
        return shareCount;
    }

    public void setShareCount(Long shareCount) {
        this.shareCount = shareCount;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }
}
